# BSVARlogMDD.R
#
# Computes log MDD for B-SVAR models
#
# Patrick T. Brandt
#
# 2006-08-27 : Initial version
# 2007-12-04 : Revised to work with MSBVAR 0.3.1
#
#

library(MSBVAR)

set.seed(789143)

##############################################
# Running tally model
##############################################

# Load posterior objects
load("runningtallyposterior.RData")

running.tally.pdf <- posterior.fit(running.tally.model,
                                   running.tally.A0)

rm(running.tally.A0)

##############################################
# Midrange model
##############################################

# Load posterior objects
load("midrangeposterior.RData")

midrange.pdf <- posterior.fit(midrange.model,
                              midrange.A0)

rm(midrange.A0)

##############################################
# Best model
##############################################

# Load posterior objects
load("bestposterior.RData")

best.pdf <- posterior.fit(best.model,
                          best.A0)

rm(best.A0)

##############################################
# Best ML model
##############################################

# Load posterior objects
load("bestMLposterior.RData")

bestML.pdf <- posterior.fit(bestML.model,
                            bestML.A0)

rm(bestML.A0)


##############################################
# Flat prior model
##############################################

# Load posterior objects
load("flatpriorposterior.RData")

# Compute the posterior summaries

flatprior.pdf <- posterior.fit(flatprior.model,
                               flatprior.A0)

rm(flatprior.A0)

#############################
# Print results
#############################
print(running.tally.pdf)
print(midrange.pdf)
print(best.pdf)
print(bestML.pdf)
print(flatprior.pdf)

# Save and exit
save.image(file="BSVARpdfs.RData", compress=T)
q(save="no")
